@@ -77,6 +77,9 @@ class Library(GObject, Thread):
 
         return map(lambda e: Song(e), playlist)
     
+    def get_by_config(self, conf):
+        pass
+    
     def search(self, config):
         where_clause = ""
         variables = ()
