@@ -1,11 +1,11 @@
 import osso
 
-from youamp import VERSION
+from youamp import context
 
 class MaemoScrobbler:
     """submits song with wrong duration after 15s of playback"""
     def __init__(self):
-        self._rpc = osso.Rpc(osso.Context("YouAmp", VERSION, False))
+        self._rpc = osso.Rpc(context)
         self._slot_free = True
         
     def send_start(self, song):
