@@ -3,18 +3,17 @@ import gobject
 import mutagen
 
 from gobject import GObject
-from youamp import Song, MAX_VOL, IS_MAEMO
-
-#from youamp.mscrobbler import MaemoScrobbler
+from youamp import Song, Playlist, MAX_VOL, IS_MAEMO
 
 class Player(GObject):
     __gsignals__ = {"song-changed": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,)),
+                    "song-played": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,)),
                     "tags-updated": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,))}
                                    
     def __init__(self, config):
         GObject.__init__(self)
         self.playing = False
-        self.playlist = None
+        self.playlist = Playlist()
         self._current = None
         self._player = None
         self._config = config
@@ -23,10 +22,11 @@ class Player(GObject):
         self._config.notify_add("volume", self._set_volume)
         self._config.notify_add("rg-preamp", lambda client, cxn_id, entry, data: self._apply_volume())
         self._config.notify_add("no-rg-preamp", lambda client, cxn_id, entry, data: self._apply_volume())
-        
-        #self._scrobbler = MaemoScrobbler()
-        
+
     def next(self, bus=None, message=None):
+        if self.get_time() > 30:
+            self.emit("song-played", self._current)
+        
         self._config["pos"] = (self._config["pos"] + 1) % len(self.playlist)        
         self.start_playback()
 
@@ -34,10 +34,16 @@ class Player(GObject):
         return len(self.playlist)
 
     def goto_pos(self, pos):
+        if self.get_time() > 30:
+            self.emit("song-played", self._current)
+
         self._config["pos"] = pos % len(self.playlist)        
         self.start_playback()
 
     def previous(self):
+        if self.get_time() > 30:
+            self.emit("song-played", self._current)
+
         self._config["pos"] = (self._config["pos"] - 1) % len(self.playlist)        
         self.start_playback()
     
@@ -68,7 +74,11 @@ class Player(GObject):
             self._player.seek_simple(gst.FORMAT_TIME, gst.SEEK_FLAG_FLUSH, int(length*pos))
 
     def load_track(self):
-        self._current = self.playlist[self._config["pos"]]
+        try:
+            self._current = self.playlist[self._config["pos"]]
+        except IndexError:
+            print "Error: invalid playlist position"
+            return
         
         if self._player is not None:
             self._player.set_state(gst.STATE_NULL)
@@ -102,7 +112,7 @@ class Player(GObject):
         #self._scrobbler.send_start(self._current)
 
     def _on_error(self, bus, message):
-        print message.parse_error()[0]
+        print "Error: %s" % message.parse_error()[0]
 
     def __del__(self):
         self._player.set_state(gst.STATE_NULL)
@@ -118,7 +128,7 @@ class Player(GObject):
         
         self.emit("tags-updated", self._current)
         
-        # FIXME immediate rg applying gives sound disortion (<=> value > 1.0)
+        # FIXME immediate rg applying gives sound disortion (<=> volume > 1.0)
         gobject.timeout_add(3000, self._apply_volume)
 
     def _on_tag(self, bus, message):
